/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.layers;

import java.beans.IntrospectionException;
import nl.cloudfarming.client.geoviewer.Layer;
import nl.cloudfarming.client.geoviewer.LayerObject;
import org.openide.nodes.Children;
import org.openide.nodes.Node;

/**
 *
 * @author Timon Veenstra
 */
public class LayerObjectChildren extends Children.Keys<LayerObject> {

    private final Layer<LayerObject<?, ?>> layer;

    public LayerObjectChildren(Layer<LayerObject<?, ?>> layer) {
        this.layer = layer;
    }

    /**
     * Called when children are first asked for nodes.
     */
    @Override
    @SuppressWarnings("unchecked")
    protected void addNotify() {
        super.addNotify();
        setKeys(layer.getObjects());
    }

    /**
     * Create nodes for a given key (category).
     *
     * @param key Key of category
     * @return
     */
    @Override
    protected Node[] createNodes(LayerObject key) {
        try {
            return new Node[]{new LayerObjectNode(layer, key)};
        } catch (IntrospectionException ex) {
            throw new RuntimeException(ex);
        }
    }
}
